# CSC 111, Day 35
# Author: John Zelle, Sara Mathieson, 111 class
# A graphics program to simulate rolling dice.


from graphics import *
import random


class Button:

    def __init__(self, x, y, w, h, label):
        """Button constructor: create a rectangle and button text."""

        # set up the boundaries of the button
        # example of simultaneous assignment
        self.xmin, self.xmax = x - w/2, x + w/2
        self.ymin, self.ymax = y - h/2, y + h/2

        # rectangle for the outline
        p1 = Point(self.xmin, self.ymin)
        p2 = Point(self.xmax, self.ymax)
        self.rect = Rectangle(p1,p2)
        self.rect.setWidth(3)

        # text of the button
        self.text = Text(Point(x,y), label)

    def draw(self, window):
        """Draw the rectangle and text on the window."""
        self.rect.draw(window)
        self.text.draw(window)

    def clicked(self, point):
        """See if the point is inside (True) or outside (False) the button."""
        x, y = point.getX(), point.getY() # simultaneous assignment

        # we can return the output of the boolean expression directly
        return self.xmin < x < self.xmax and self.ymin < y < self.ymax


class DieView:

    def __init__(self, x, y, size):
        """DieView constructor: make a square of the given size and 7 pips."""

        # define a few instance variables that we'll use throughout
        self.background = "yellow"
        self.foreground = "purple"
        self.pip_size = 6

        # make a square for the die outline
        p1 = Point(x-size/2,y-size/2)
        p2 = Point(x+size/2,y+size/2)
        self.square = Rectangle(p1, p2)
        self.square.setFill(self.background)

        # draw all pips
        offset = size/4
        pip0 = self.make_pip(x-offset, y-offset)
        pip1 = self.make_pip(x-offset, y)
        pip2 = self.make_pip(x-offset, y+offset)
        pip3 = self.make_pip(x, y)
        pip4 = self.make_pip(x+offset, y-offset)
        pip5 = self.make_pip(x+offset, y)
        pip6 = self.make_pip(x+offset, y+offset)

        # create an instance variable for the list of pips
        self.pip_lst = [pip0, pip1, pip2, pip3, pip4, pip5, pip6]

        # choose a random value to start (call helper method!)
        self.set_value(random.randint(1,6))

    def draw(self, window):
        """Draw the square and the pips."""
        self.square.draw(window)
        for pip in self.pip_lst:
            pip.draw(window)

    def make_pip(self, x, y):
        """Create a pip (small circle) at the given (x,y) position."""
        pip = Circle(Point(x,y), self.pip_size)
        pip.setFill(self.background)
        pip.setOutline(self.background)
        return pip

    def set_value(self, value):
        """Change which pips are the foreground color to simulate
        rolling a different number (value should be one of: 1,2,3,4,5,6)."""

        # first set ALL the pips back to the background color
        for pip in self.pip_lst:
            pip.setFill(self.background)

        # based on the value, define a custom list of pips to be "on"
        if value == 1:
            pips_on = [3]
        elif value == 2:
            pips_on = [0,6]
        elif value == 3:
            pips_on = [0,3,6]
        elif value == 4:
            pips_on = [0,2,4,6]
        elif value == 5:
            pips_on = [0,2,3,4,6]
        elif value == 6:
            pips_on = [0,1,2,4,5,6]

        # for each of the "on" pips, change its color to the foreground
        for i in pips_on:
            self.pip_lst[i].setFill(self.foreground)


def main():
    """When the button is clicked, roll the dice."""

    # set up a window (default width and height are both 200)
    win = GraphWin("Dice Roller")

    # parameters: (x,y) of center, width, height, label
    roll = Button(100, 150, 60, 20, "Roll Dice")
    roll.draw(win)

    # use the DieView constructor to make a set of dice
    die1 = DieView(50,70,60)
    die2 = DieView(150,70,60)
    die1.draw(win)
    die2.draw(win)

    # keep asking the user for a click
    while True:
        p = win.getMouse() # wait for the user to click

        # if user clicked on the button, roll the dice
        if roll.clicked(p):
            die1.set_value(random.randint(1,6))
            die2.set_value(random.randint(1,6))


main()

        
